
### git更换
```shell
git init
git remote add origin https://gitee.com/python-playing/afeng-py-tools.git
git add .
git commit -m 'init project'
git push -u origin master
```

###  打包
```shell
pip install setuptools_scm
pip install --upgrade build
python -m build
```
### 上传
```shell
pip install --upgrade twine
```
#### 测试上传
```shell
# 测试上传
python -m twine upload --repository testpypi dist/*
```
#### 验证测试包
```shell
pip install -i https://test.pypi.org/simple/ afeng-py-tools --no-deps
```
测试代码如下：
```python
from afeng_tools.sqlalchemy_tool import sqlalchemy_tools
from afeng_tools.template_tool.core import js_tools

print(sqlalchemy_tools.add_one(3))
print(js_tools.min_js('var test=1;'))
```
#### 正式上传
```shell
python -m twine upload dist/*
```
